import typing

import android.content
import android.content.res
import android.net
import android.os
import android.view
import java
import java.lang
import java.util
import java.util.concurrent

class EmbeddedPhotoPickerClient(java.lang.Object):
    def onSelectionComplete(self) -> None: ...
    def onSessionError(self, arg1: java.lang.Throwable, /) -> None: ...
    def onSessionOpened(self, arg1: EmbeddedPhotoPickerSession, /) -> None: ...
    def onUriPermissionGranted(self, arg1: java.util.List[android.net.Uri], /) -> None: ...
    def onUriPermissionRevoked(self, arg1: java.util.List[android.net.Uri], /) -> None: ...

class EmbeddedPhotoPickerFeatureInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[EmbeddedPhotoPickerFeatureInfo]] = ...
    def describeContents(self) -> int: ...
    def getAccentColor(self) -> int: ...
    def getMaxSelectionLimit(self) -> int: ...
    def getMimeTypes(self) -> java.util.List[java.lang.String]: ...
    def getPreSelectedUris(self) -> java.util.List[android.net.Uri]: ...
    def getThemeNightMode(self) -> int: ...
    def isOrderedSelection(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> EmbeddedPhotoPickerFeatureInfo: ...
        def setAccentColor(self, accentColor: int | java.jlong | java.lang.Long, /) -> EmbeddedPhotoPickerFeatureInfo.Builder: ...
        def setMaxSelectionLimit(self, maxSelectionLimit: int | java.jint | java.lang.Integer, /) -> EmbeddedPhotoPickerFeatureInfo.Builder: ...
        def setMimeTypes(self, mimeTypes: java.util.List[java.lang.String], /) -> EmbeddedPhotoPickerFeatureInfo.Builder: ...
        def setOrderedSelection(self, orderedSelection: bool | java.jboolean | java.lang.Boolean, /) -> EmbeddedPhotoPickerFeatureInfo.Builder: ...
        def setPreSelectedUris(self, preSelectedUris: java.util.List[android.net.Uri], /) -> EmbeddedPhotoPickerFeatureInfo.Builder: ...
        def setThemeNightMode(self, themeNightMode: int | java.jint | java.lang.Integer, /) -> EmbeddedPhotoPickerFeatureInfo.Builder: ...

class EmbeddedPhotoPickerProvider(java.lang.Object):
    def openSession(self, arg1: android.os.IBinder, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: EmbeddedPhotoPickerFeatureInfo, arg6: java.util.concurrent.Executor, arg7: EmbeddedPhotoPickerClient, /) -> None: ...

class EmbeddedPhotoPickerProviderFactory(java.lang.Object):
    @staticmethod
    def create(context: android.content.Context, /) -> EmbeddedPhotoPickerProvider: ...

class EmbeddedPhotoPickerSession(java.lang.Object):
    def close(self) -> None: ...
    def getSurfacePackage(self) -> android.view.SurfaceControlViewHost.SurfacePackage: ...
    def notifyConfigurationChanged(self, arg1: android.content.res.Configuration, /) -> None: ...
    def notifyPhotoPickerExpanded(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def notifyResized(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def notifyVisibilityChanged(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def requestRevokeUriPermission(self, arg1: java.util.List[android.net.Uri], /) -> None: ...



import typing

from java.lang import Object, Throwable
from java.primitive import (
    Primitive,
    jboolean,
    jbyte,
    jchar,
    jdouble,
    jfloat,
    jint,
    jlong,
    jshort,
)

# class.pxi #######################################################################################
def jclass(clsname: str) -> type[Object]: ...

# array.pxi #######################################################################################
_JAVA_OBJ = Primitive | Object

JAVA_OBJ_T = typing.TypeVar("JAVA_OBJ_T", bound=_JAVA_OBJ)

class JavaArray(Object, typing.Sequence[JAVA_OBJ_T]):
    def __init__(
        self,
        length_or_value: int | typing.Sequence[JAVA_OBJ_T],
    ): ...
    def __len__(self): ...
    @typing.overload
    def __getitem__(
        self,
        key: int,
    ) -> JAVA_OBJ_T: ...
    @typing.overload
    def __getitem__(
        self,
        key: slice,
    ) -> JavaArray[JAVA_OBJ_T]: ...
    def copy(self) -> JavaArray[JAVA_OBJ_T]: ...
    def __copy__(self) -> JavaArray[JAVA_OBJ_T]: ...
    @typing.overload
    def __setitem__(
        self,
        key: int,
        value: JAVA_OBJ_T,
    ): ...
    @typing.overload
    def __setitem__(
        self,
        key: slice,
        value: typing.Sequence[JAVA_OBJ_T],
    ): ...
    def __eq__(self, other: typing.Any) -> bool: ...
    def __add__(self, other: JavaArray[JAVA_OBJ_T]) -> JavaArray[JAVA_OBJ_T]: ...
    def __radd__(self, other: JavaArray[JAVA_OBJ_T]) -> JavaArray[JAVA_OBJ_T]: ...
    def __contains__(self, value: typing.Any): ...
    def __iter__(self) -> typing.Iterator[JAVA_OBJ_T]: ...
    def __reversed__(self) -> typing.Iterator[JAVA_OBJ_T]: ...
    def index(self, value: typing.Any, start: int = 0, stop: int = ...) -> int: ...
    def count(self, value: typing.Any) -> int: ...

# inference of correct type is not working, when overloading __init__ with mypy v1.15.0
class JavaArrayJBoolean(JavaArray[jboolean]):
    def __init__(
        self,
        length_or_value: int | typing.Sequence[jboolean | bool],
    ): ...
    @typing.overload
    def __setitem__(
        self,
        key: int,
        value: jboolean | bool,
    ): ...
    @typing.overload
    def __setitem__(
        self,
        key: slice,
        value: typing.Sequence[jboolean | bool],
    ): ...
    def __buffer__(self, flags: int, /) -> memoryview: ...

class JavaArrayJByte(JavaArray[jbyte]):
    def __init__(
        self,
        length_or_value: int | typing.Sequence[jbyte | int],
    ): ...
    @typing.overload
    def __setitem__(
        self,
        key: int,
        value: jbyte | int,
    ): ...
    @typing.overload
    def __setitem__(
        self,
        key: slice,
        value: typing.Sequence[jbyte | int],
    ): ...
    def __buffer__(self, flags: int, /) -> memoryview: ...

class JavaArrayJShort(JavaArray[jshort]):
    def __init__(
        self,
        length_or_value: int | typing.Sequence[jshort | int],
    ): ...
    @typing.overload
    def __setitem__(
        self,
        key: int,
        value: jshort | int,
    ): ...
    @typing.overload
    def __setitem__(
        self,
        key: slice,
        value: typing.Sequence[jshort | int],
    ): ...
    def __buffer__(self, flags: int, /) -> memoryview: ...

class JavaArrayJInt(JavaArray[jint]):
    def __init__(
        self,
        length_or_value: int | typing.Sequence[jint | int],
    ): ...
    @typing.overload
    def __setitem__(
        self,
        key: int,
        value: jint | int,
    ): ...
    @typing.overload
    def __setitem__(
        self,
        key: slice,
        value: typing.Sequence[jint | int],
    ): ...
    def __buffer__(self, flags: int, /) -> memoryview: ...

class JavaArrayJLong(JavaArray[jlong]):
    def __init__(
        self,
        length_or_value: int | typing.Sequence[jlong | int],
    ): ...
    @typing.overload
    def __setitem__(
        self,
        key: int,
        value: jlong | int,
    ): ...
    @typing.overload
    def __setitem__(
        self,
        key: slice,
        value: typing.Sequence[jlong | int],
    ): ...
    def __buffer__(self, flags: int, /) -> memoryview: ...

class JavaArrayJFloat(JavaArray[jfloat]):
    def __init__(
        self,
        length_or_value: int | typing.Sequence[jfloat | float],
    ): ...
    @typing.overload
    def __setitem__(
        self,
        key: int,
        value: jfloat | float,
    ): ...
    @typing.overload
    def __setitem__(
        self,
        key: slice,
        value: typing.Sequence[jfloat | float],
    ): ...
    def __buffer__(self, flags: int, /) -> memoryview: ...

class JavaArrayJDouble(JavaArray[jdouble]):
    def __init__(
        self,
        length_or_value: int | typing.Sequence[jdouble | float],
    ): ...
    @typing.overload
    def __setitem__(
        self,
        key: int,
        value: jdouble | float,
    ): ...
    @typing.overload
    def __setitem__(
        self,
        key: slice,
        value: typing.Sequence[jdouble | float],
    ): ...
    def __buffer__(self, flags: int, /) -> memoryview: ...

class JavaArrayJChar(JavaArray[jchar]):
    def __init__(
        self,
        length_or_value: int | typing.Sequence[jchar | str] | str,
    ): ...
    @typing.overload
    def __setitem__(
        self,
        key: int,
        value: str,
    ): ...
    @typing.overload
    def __setitem__(
        self,
        key: slice,
        value: typing.Sequence[jchar | str] | str,
    ): ...
    

@typing.overload
def jarray(
    element_type: typing.Type[jboolean],
) -> typing.Type[JavaArrayJBoolean]: ...
@typing.overload
def jarray(
    element_type: typing.Type[jbyte],
) -> typing.Type[JavaArrayJByte]: ...
@typing.overload
def jarray(
    element_type: typing.Type[jshort],
) -> typing.Type[JavaArrayJShort]: ...
@typing.overload
def jarray(
    element_type: typing.Type[jint],
) -> typing.Type[JavaArrayJInt]: ...
@typing.overload
def jarray(
    element_type: typing.Type[jlong],
) -> typing.Type[JavaArrayJLong]: ...
@typing.overload
def jarray(
    element_type: typing.Type[jfloat],
) -> typing.Type[JavaArrayJFloat]: ...
@typing.overload
def jarray(
    element_type: typing.Type[jdouble],
) -> typing.Type[JavaArrayJDouble]: ...
@typing.overload
def jarray(
    element_type: typing.Type[jchar],
) -> typing.Type[JavaArrayJChar]: ...
@typing.overload
def jarray(
    element_type: typing.Type[JAVA_OBJ_T],
) -> typing.Type[JavaArray[JAVA_OBJ_T]]: ...
@typing.overload
def jarray(element_type: str) -> typing.Type[JavaArray[typing.Any]]: ...

# import.pxi #######################################################################################
def set_import_enabled(enable: bool): ...

# proxy.pxi #######################################################################################
T = typing.TypeVar("T")

@typing.overload
def dynamic_proxy(
    __i1: typing.Type[T],
) -> typing.Type[T]: ...
@typing.overload
def dynamic_proxy(
    # intersection of classes is not supported in type hints, so we use Any here
    *implements: typing.Type[typing.Any],
) -> typing.Type[typing.Any]: ...

JAVA_CLASS_T = typing.TypeVar("JAVA_CLASS_T", bound=Object)

@typing.overload
def static_proxy(
    extends: typing.Type[JAVA_CLASS_T],
    # intersection of classes is not supported in type hints, so we use Any here
    *implements: typing.Type[typing.Any],
    package: str | None = ...,
    modifiers: str = "public",
) -> typing.Type[JAVA_CLASS_T]: ...
@typing.overload
def static_proxy(
    extends: None = ...,
    # intersection of classes is not supported in type hints, so we use Any here
    *implements: typing.Type[typing.Any],
    package: str | None = ...,
    modifiers: str = "public",
) -> typing.Type[Object]: ...
def constructor(
    arg_types: typing.Sequence[typing.Type[_JAVA_OBJ]],
    *,
    modifiers: str = "public",
    throws: typing.Sequence[typing.Type[Throwable]] | None = None,
) -> typing.Callable[[typing.Callable[..., typing.Any]], typing.Callable[..., typing.Any]]: ...
def method(
    return_type: typing.Type[_JAVA_OBJ],
    arg_types: typing.Sequence[typing.Type[_JAVA_OBJ]],
    *,
    modifiers: str = "public",
    throws: typing.Sequence[typing.Type[Throwable]] | None = None,
) -> typing.Callable[[typing.Callable[..., typing.Any]], typing.Callable[..., typing.Any]]: ...
def Override(
    return_type: typing.Type[_JAVA_OBJ],
    arg_types: typing.Sequence[typing.Type[_JAVA_OBJ]],
    *,
    modifiers: str = "public",
    throws: typing.Sequence[typing.Type[Throwable]] | None = None,
) -> typing.Callable[[typing.Callable[..., typing.Any]], typing.Callable[..., typing.Any]]: ...

# utils.pxi #######################################################################################
def cast(cls: typing.Type[T], obj: typing.Any) -> T: ...

# jvm.pxi #######################################################################################
def detach() -> None: ...



import typing

import android.net
import android.os
import java
import java.chaquopy
import java.lang
import java.net
import java.util
import java.util.concurrent

class AdvertisingRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AdvertisingRequest]] = ...
    FLAG_SKIP_PROBING: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getFlags(self) -> int: ...
    def getProtocolType(self) -> int: ...
    def getServiceInfo(self) -> NsdServiceInfo: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, serviceInfo: NsdServiceInfo, /) -> None: ...
        def build(self) -> AdvertisingRequest: ...
        def setFlags(self, flags: int | java.jlong | java.lang.Long, /) -> AdvertisingRequest.Builder: ...
        def setProtocolType(self, protocolType: int | java.jint | java.lang.Integer, /) -> AdvertisingRequest.Builder: ...

class DiscoveryRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[DiscoveryRequest]] = ...
    def describeContents(self) -> int: ...
    def equals(self, other: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getNetwork(self) -> android.net.Network | None: ...
    def getServiceType(self) -> str: ...
    def getSubtype(self) -> str | None: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, serviceType: str | java.lang.String, /) -> None: ...
        def build(self) -> DiscoveryRequest: ...
        def setNetwork(self, network: android.net.Network, /) -> DiscoveryRequest.Builder: ...
        def setSubtype(self, subtype: str | java.lang.String, /) -> DiscoveryRequest.Builder: ...

class NsdManager(java.lang.Object):
    ACTION_NSD_STATE_CHANGED: typing.ClassVar[str] = ...
    EXTRA_NSD_STATE: typing.ClassVar[str] = ...
    FAILURE_ALREADY_ACTIVE: typing.ClassVar[int] = ...
    FAILURE_BAD_PARAMETERS: typing.ClassVar[int] = ...
    FAILURE_INTERNAL_ERROR: typing.ClassVar[int] = ...
    FAILURE_MAX_LIMIT: typing.ClassVar[int] = ...
    FAILURE_OPERATION_NOT_RUNNING: typing.ClassVar[int] = ...
    NSD_STATE_DISABLED: typing.ClassVar[int] = ...
    NSD_STATE_ENABLED: typing.ClassVar[int] = ...
    PROTOCOL_DNS_SD: typing.ClassVar[int] = ...
    @typing.overload
    def discoverServices(self, discoveryRequest: DiscoveryRequest, executor: java.util.concurrent.Executor, listener: NsdManager.DiscoveryListener, /) -> None: ...
    @typing.overload
    def discoverServices(self, serviceType: str | java.lang.String, protocolType: int | java.jint | java.lang.Integer, listener: NsdManager.DiscoveryListener, /) -> None: ...
    @typing.overload
    def discoverServices(self, serviceType: str | java.lang.String, protocolType: int | java.jint | java.lang.Integer, network: android.net.Network, executor: java.util.concurrent.Executor, listener: NsdManager.DiscoveryListener, /) -> None: ...
    @typing.overload
    def discoverServices(self, serviceType: str | java.lang.String, protocolType: int | java.jint | java.lang.Integer, networkRequest: android.net.NetworkRequest, executor: java.util.concurrent.Executor, listener: NsdManager.DiscoveryListener, /) -> None: ...
    @typing.overload
    def registerService(self, serviceInfo: NsdServiceInfo, protocolType: int | java.jint | java.lang.Integer, listener: NsdManager.RegistrationListener, /) -> None: ...
    @typing.overload
    def registerService(self, serviceInfo: NsdServiceInfo, protocolType: int | java.jint | java.lang.Integer, executor: java.util.concurrent.Executor, listener: NsdManager.RegistrationListener, /) -> None: ...
    def registerServiceInfoCallback(self, serviceInfo: NsdServiceInfo, executor: java.util.concurrent.Executor, listener: NsdManager.ServiceInfoCallback, /) -> None: ...
    @typing.overload
    def resolveService(self, serviceInfo: NsdServiceInfo, listener: NsdManager.ResolveListener, /) -> None: ...
    @typing.overload
    def resolveService(self, serviceInfo: NsdServiceInfo, executor: java.util.concurrent.Executor, listener: NsdManager.ResolveListener, /) -> None: ...
    def stopServiceDiscovery(self, listener: NsdManager.DiscoveryListener, /) -> None: ...
    def stopServiceResolution(self, listener: NsdManager.ResolveListener, /) -> None: ...
    def unregisterService(self, listener: NsdManager.RegistrationListener, /) -> None: ...
    def unregisterServiceInfoCallback(self, listener: NsdManager.ServiceInfoCallback, /) -> None: ...

    class ServiceInfoCallback(java.lang.Object):
        def onServiceInfoCallbackRegistrationFailed(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
        def onServiceInfoCallbackUnregistered(self) -> None: ...
        def onServiceLost(self) -> None: ...
        def onServiceUpdated(self, arg1: NsdServiceInfo, /) -> None: ...

    class ResolveListener(java.lang.Object):
        def onResolutionStopped(self, serviceInfo: NsdServiceInfo, /) -> None: ...
        def onResolveFailed(self, arg1: NsdServiceInfo, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
        def onServiceResolved(self, arg1: NsdServiceInfo, /) -> None: ...
        def onStopResolutionFailed(self, serviceInfo: NsdServiceInfo, errorCode: int | java.jint | java.lang.Integer, /) -> None: ...

    class RegistrationListener(java.lang.Object):
        def onRegistrationFailed(self, arg1: NsdServiceInfo, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
        def onServiceRegistered(self, arg1: NsdServiceInfo, /) -> None: ...
        def onServiceUnregistered(self, arg1: NsdServiceInfo, /) -> None: ...
        def onUnregistrationFailed(self, arg1: NsdServiceInfo, arg2: int | java.jint | java.lang.Integer, /) -> None: ...

    class DiscoveryListener(java.lang.Object):
        def onDiscoveryStarted(self, arg1: str | java.lang.String, /) -> None: ...
        def onDiscoveryStopped(self, arg1: str | java.lang.String, /) -> None: ...
        def onServiceFound(self, arg1: NsdServiceInfo, /) -> None: ...
        def onServiceLost(self, arg1: NsdServiceInfo, /) -> None: ...
        def onStartDiscoveryFailed(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
        def onStopDiscoveryFailed(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, /) -> None: ...

class NsdServiceInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[NsdServiceInfo]] = ...
    def __init__(self) -> None: ...
    def describeContents(self) -> int: ...
    def getAttributes(self) -> java.util.Map[java.lang.String, java.chaquopy.JavaArrayJByte]: ...
    def getHost(self) -> java.net.InetAddress: ...
    def getHostAddresses(self) -> java.util.List[java.net.InetAddress]: ...
    def getHostname(self) -> str: ...
    def getNetwork(self) -> android.net.Network | None: ...
    def getPort(self) -> int: ...
    def getServiceName(self) -> str: ...
    def getServiceType(self) -> str: ...
    def getSubtypes(self) -> java.util.Set[java.lang.String]: ...
    def removeAttribute(self, key: str | java.lang.String, /) -> None: ...
    def setAttribute(self, key: str | java.lang.String, value: str | java.lang.String, /) -> None: ...
    def setHost(self, s: java.net.InetAddress, /) -> None: ...
    def setHostAddresses(self, addresses: java.util.List[java.net.InetAddress], /) -> None: ...
    def setNetwork(self, network: android.net.Network, /) -> None: ...
    def setPort(self, p: int | java.jint | java.lang.Integer, /) -> None: ...
    def setServiceName(self, s: str | java.lang.String, /) -> None: ...
    def setServiceType(self, s: str | java.lang.String, /) -> None: ...
    def setSubtypes(self, subtypes: java.util.Set[java.lang.String], /) -> None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...



import java.chaquopy
import java.lang
import java.lang.annotation

class Generated(java.lang.annotation.Annotation):
    def comments(self) -> str: ...
    def date(self) -> str: ...
    def value(self) -> java.chaquopy.JavaArray[java.lang.String]: ...



import typing

import android.text
import android.text.style
import android.widget
import java
import java.chaquopy
import java.lang
import java.util
import java.util.function
import java.util.regex

class Linkify(java.lang.Object):
    ALL: typing.ClassVar[int] = ...
    EMAIL_ADDRESSES: typing.ClassVar[int] = ...
    MAP_ADDRESSES: typing.ClassVar[int] = ...
    PHONE_NUMBERS: typing.ClassVar[int] = ...
    WEB_URLS: typing.ClassVar[int] = ...
    sPhoneNumberMatchFilter: typing.ClassVar[Linkify.MatchFilter] = ...
    sPhoneNumberTransformFilter: typing.ClassVar[Linkify.TransformFilter] = ...
    sUrlMatchFilter: typing.ClassVar[Linkify.MatchFilter] = ...
    def __init__(self) -> None: ...
    @typing.overload
    @staticmethod
    def addLinks(text: android.text.Spannable, mask: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    @staticmethod
    def addLinks(text: android.widget.TextView, mask: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    @staticmethod
    def addLinks(text: android.text.Spannable, mask: int | java.jint | java.lang.Integer, urlSpanFactory: java.util.function.Function[java.lang.String, android.text.style.URLSpan], /) -> bool: ...
    @typing.overload
    @staticmethod
    def addLinks(text: android.text.Spannable, pattern: java.util.regex.Pattern, scheme: str | java.lang.String, /) -> bool: ...
    @typing.overload
    @staticmethod
    def addLinks(text: android.widget.TextView, pattern: java.util.regex.Pattern, scheme: str | java.lang.String, /) -> None: ...
    @typing.overload
    @staticmethod
    def addLinks(spannable: android.text.Spannable, pattern: java.util.regex.Pattern, scheme: str | java.lang.String, matchFilter: Linkify.MatchFilter, transformFilter: Linkify.TransformFilter, /) -> bool: ...
    @typing.overload
    @staticmethod
    def addLinks(text: android.widget.TextView, pattern: java.util.regex.Pattern, scheme: str | java.lang.String, matchFilter: Linkify.MatchFilter, transformFilter: Linkify.TransformFilter, /) -> None: ...
    @typing.overload
    @staticmethod
    def addLinks(spannable: android.text.Spannable, pattern: java.util.regex.Pattern, defaultScheme: str | java.lang.String, schemes: java.chaquopy.JavaArray[java.lang.String], matchFilter: Linkify.MatchFilter, transformFilter: Linkify.TransformFilter, /) -> bool: ...
    @typing.overload
    @staticmethod
    def addLinks(text: android.widget.TextView, pattern: java.util.regex.Pattern, defaultScheme: str | java.lang.String, schemes: java.chaquopy.JavaArray[java.lang.String], matchFilter: Linkify.MatchFilter, transformFilter: Linkify.TransformFilter, /) -> None: ...
    @typing.overload
    @staticmethod
    def addLinks(spannable: android.text.Spannable, pattern: java.util.regex.Pattern, defaultScheme: str | java.lang.String, schemes: java.chaquopy.JavaArray[java.lang.String], matchFilter: Linkify.MatchFilter, transformFilter: Linkify.TransformFilter, urlSpanFactory: java.util.function.Function[java.lang.String, android.text.style.URLSpan], /) -> bool: ...

    class MatchFilter(java.lang.Object):
        def acceptMatch(self, arg1: java.lang.CharSequence, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> bool: ...

    class TransformFilter(java.lang.Object):
        def transformUrl(self, arg1: java.util.regex.Matcher, arg2: str | java.lang.String, /) -> str: ...

class Rfc822Token(java.lang.Object):
    def __init__(self, name: str | java.lang.String, address: str | java.lang.String, comment: str | java.lang.String, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAddress(self) -> str | None: ...
    def getComment(self) -> str | None: ...
    def getName(self) -> str | None: ...
    def hashCode(self) -> int: ...
    @staticmethod
    def quoteComment(comment: str | java.lang.String, /) -> str: ...
    @staticmethod
    def quoteName(name: str | java.lang.String, /) -> str: ...
    @staticmethod
    def quoteNameIfNecessary(name: str | java.lang.String, /) -> str: ...
    def setAddress(self, address: str | java.lang.String, /) -> None: ...
    def setComment(self, comment: str | java.lang.String, /) -> None: ...
    def setName(self, name: str | java.lang.String, /) -> None: ...
    def toString(self) -> str: ...

class Rfc822Tokenizer(android.widget.MultiAutoCompleteTextView.Tokenizer):
    def __init__(self) -> None: ...
    def findTokenEnd(self, text: java.lang.CharSequence, cursor: int | java.jint | java.lang.Integer, /) -> int: ...
    def findTokenStart(self, text: java.lang.CharSequence, cursor: int | java.jint | java.lang.Integer, /) -> int: ...
    def terminateToken(self, text: java.lang.CharSequence, /) -> java.lang.CharSequence: ...
    @typing.overload
    @staticmethod
    def tokenize(text: java.lang.CharSequence, /) -> java.chaquopy.JavaArray[Rfc822Token]: ...
    @typing.overload
    @staticmethod
    def tokenize(text: java.lang.CharSequence, out: java.util.Collection[Rfc822Token], /) -> None: ...



import typing

import android.app
import android.content
import android.content.pm
import android.database
import android.graphics.drawable
import android.net
import android.os
import java
import java.chaquopy
import java.lang
import java.util

class Slice(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[Slice]] = ...
    EXTRA_RANGE_VALUE: typing.ClassVar[str] = ...
    EXTRA_TOGGLE_STATE: typing.ClassVar[str] = ...
    HINT_ACTIONS: typing.ClassVar[str] = ...
    HINT_ERROR: typing.ClassVar[str] = ...
    HINT_HORIZONTAL: typing.ClassVar[str] = ...
    HINT_KEYWORDS: typing.ClassVar[str] = ...
    HINT_LARGE: typing.ClassVar[str] = ...
    HINT_LAST_UPDATED: typing.ClassVar[str] = ...
    HINT_LIST: typing.ClassVar[str] = ...
    HINT_LIST_ITEM: typing.ClassVar[str] = ...
    HINT_NO_TINT: typing.ClassVar[str] = ...
    HINT_PARTIAL: typing.ClassVar[str] = ...
    HINT_PERMISSION_REQUEST: typing.ClassVar[str] = ...
    HINT_SEE_MORE: typing.ClassVar[str] = ...
    HINT_SELECTED: typing.ClassVar[str] = ...
    HINT_SHORTCUT: typing.ClassVar[str] = ...
    HINT_SUMMARY: typing.ClassVar[str] = ...
    HINT_TITLE: typing.ClassVar[str] = ...
    HINT_TTL: typing.ClassVar[str] = ...
    SUBTYPE_COLOR: typing.ClassVar[str] = ...
    SUBTYPE_CONTENT_DESCRIPTION: typing.ClassVar[str] = ...
    SUBTYPE_LAYOUT_DIRECTION: typing.ClassVar[str] = ...
    SUBTYPE_MAX: typing.ClassVar[str] = ...
    SUBTYPE_MESSAGE: typing.ClassVar[str] = ...
    SUBTYPE_MILLIS: typing.ClassVar[str] = ...
    SUBTYPE_PRIORITY: typing.ClassVar[str] = ...
    SUBTYPE_RANGE: typing.ClassVar[str] = ...
    SUBTYPE_SOURCE: typing.ClassVar[str] = ...
    SUBTYPE_TOGGLE: typing.ClassVar[str] = ...
    SUBTYPE_VALUE: typing.ClassVar[str] = ...
    def __init__(self, in_: android.os.Parcel, /) -> None: ...
    def describeContents(self) -> int: ...
    def getHints(self) -> java.util.List[java.lang.String]: ...
    def getItems(self) -> java.util.List[SliceItem]: ...
    def getSpec(self) -> SliceSpec | None: ...
    def getUri(self) -> android.net.Uri: ...
    def isCallerNeeded(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self, parent: Slice.Builder, /) -> None: ...
        @typing.overload
        def __init__(self, uri: android.net.Uri, spec: SliceSpec, /) -> None: ...
        def addAction(self, action: android.app.PendingIntent, s: Slice, subType: str | java.lang.String, /) -> Slice.Builder: ...
        def addBundle(self, bundle: android.os.Bundle, subType: str | java.lang.String, hints: java.util.List[java.lang.String], /) -> Slice.Builder: ...
        def addHints(self, hints: java.util.List[java.lang.String], /) -> Slice.Builder: ...
        def addIcon(self, icon: android.graphics.drawable.Icon, subType: str | java.lang.String, hints: java.util.List[java.lang.String], /) -> Slice.Builder: ...
        def addInt(self, value: int | java.jint | java.lang.Integer, subType: str | java.lang.String, hints: java.util.List[java.lang.String], /) -> Slice.Builder: ...
        def addLong(self, value: int | java.jlong | java.lang.Long, subType: str | java.lang.String, hints: java.util.List[java.lang.String], /) -> Slice.Builder: ...
        def addRemoteInput(self, remoteInput: android.app.RemoteInput, subType: str | java.lang.String, hints: java.util.List[java.lang.String], /) -> Slice.Builder: ...
        def addSubSlice(self, slice: Slice, subType: str | java.lang.String, /) -> Slice.Builder: ...
        def addText(self, text: java.lang.CharSequence, subType: str | java.lang.String, hints: java.util.List[java.lang.String], /) -> Slice.Builder: ...
        def build(self) -> Slice: ...
        def setCallerNeeded(self, callerNeeded: bool | java.jboolean | java.lang.Boolean, /) -> Slice.Builder: ...

class SliceItem(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SliceItem]] = ...
    FORMAT_ACTION: typing.ClassVar[str] = ...
    FORMAT_BUNDLE: typing.ClassVar[str] = ...
    FORMAT_IMAGE: typing.ClassVar[str] = ...
    FORMAT_INT: typing.ClassVar[str] = ...
    FORMAT_LONG: typing.ClassVar[str] = ...
    FORMAT_REMOTE_INPUT: typing.ClassVar[str] = ...
    FORMAT_SLICE: typing.ClassVar[str] = ...
    FORMAT_TEXT: typing.ClassVar[str] = ...
    def describeContents(self) -> int: ...
    def getAction(self) -> android.app.PendingIntent: ...
    def getBundle(self) -> android.os.Bundle: ...
    def getFormat(self) -> str: ...
    def getHints(self) -> java.util.List[java.lang.String]: ...
    def getIcon(self) -> android.graphics.drawable.Icon: ...
    def getInt(self) -> int: ...
    def getLong(self) -> int: ...
    def getRemoteInput(self) -> android.app.RemoteInput: ...
    def getSlice(self) -> Slice: ...
    def getSubType(self) -> str: ...
    def getText(self) -> java.lang.CharSequence: ...
    def hasHint(self, hint: str | java.lang.String, /) -> bool: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class SliceManager(java.lang.Object):
    CATEGORY_SLICE: typing.ClassVar[str] = ...
    SLICE_METADATA_KEY: typing.ClassVar[str] = ...
    @typing.overload
    def bindSlice(self, intent: android.content.Intent, supportedSpecs: java.util.Set[SliceSpec], /) -> Slice | None: ...
    @typing.overload
    def bindSlice(self, uri: android.net.Uri, supportedSpecs: java.util.Set[SliceSpec], /) -> Slice | None: ...
    def checkSlicePermission(self, uri: android.net.Uri, pid: int | java.jint | java.lang.Integer, uid: int | java.jint | java.lang.Integer, /) -> int: ...
    def getPinnedSlices(self) -> java.util.List[android.net.Uri]: ...
    def getPinnedSpecs(self, uri: android.net.Uri, /) -> java.util.Set[SliceSpec]: ...
    def getSliceDescendants(self, uri: android.net.Uri, /) -> java.util.Collection[android.net.Uri]: ...
    def grantSlicePermission(self, toPackage: str | java.lang.String, uri: android.net.Uri, /) -> None: ...
    def mapIntentToUri(self, intent: android.content.Intent, /) -> android.net.Uri | None: ...
    def pinSlice(self, uri: android.net.Uri, specs: java.util.Set[SliceSpec], /) -> None: ...
    def revokeSlicePermission(self, toPackage: str | java.lang.String, uri: android.net.Uri, /) -> None: ...
    def unpinSlice(self, uri: android.net.Uri, /) -> None: ...

class SliceMetrics(java.lang.Object):
    def __init__(self, context: android.content.Context, uri: android.net.Uri, /) -> None: ...
    def logHidden(self) -> None: ...
    def logTouch(self, actionType: int | java.jint | java.lang.Integer, subSlice: android.net.Uri, /) -> None: ...
    def logVisible(self) -> None: ...

class SliceProvider(android.content.ContentProvider):
    SLICE_TYPE: typing.ClassVar[str] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, *autoGrantPermissions: java.lang.String) -> None: ...
    def attachInfo(self, context: android.content.Context, info: android.content.pm.ProviderInfo, /) -> None: ...
    def call(self, method: str | java.lang.String, arg: str | java.lang.String, extras: android.os.Bundle, /) -> android.os.Bundle: ...
    def delete(self, uri: android.net.Uri, selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], /) -> int: ...
    def getType(self, uri: android.net.Uri, /) -> str: ...
    def insert(self, uri: android.net.Uri, values: android.content.ContentValues, /) -> android.net.Uri: ...
    def onBindSlice(self, sliceUri: android.net.Uri, supportedSpecs: java.util.Set[SliceSpec], /) -> Slice: ...
    def onCreatePermissionRequest(self, sliceUri: android.net.Uri, /) -> android.app.PendingIntent: ...
    def onGetSliceDescendants(self, uri: android.net.Uri, /) -> java.util.Collection[android.net.Uri]: ...
    def onMapIntentToUri(self, intent: android.content.Intent, /) -> android.net.Uri: ...
    def onSlicePinned(self, sliceUri: android.net.Uri, /) -> None: ...
    def onSliceUnpinned(self, sliceUri: android.net.Uri, /) -> None: ...
    @typing.overload
    def query(self, uri: android.net.Uri, projection: java.chaquopy.JavaArray[java.lang.String], queryArgs: android.os.Bundle, cancellationSignal: android.os.CancellationSignal, /) -> android.database.Cursor: ...
    @typing.overload
    def query(self, uri: android.net.Uri, projection: java.chaquopy.JavaArray[java.lang.String], selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], sortOrder: str | java.lang.String, /) -> android.database.Cursor: ...
    @typing.overload
    def query(self, uri: android.net.Uri, projection: java.chaquopy.JavaArray[java.lang.String], selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], sortOrder: str | java.lang.String, cancellationSignal: android.os.CancellationSignal, /) -> android.database.Cursor: ...
    def update(self, uri: android.net.Uri, values: android.content.ContentValues, selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], /) -> int: ...

class SliceSpec(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SliceSpec]] = ...
    def __init__(self, type: str | java.lang.String, revision: int | java.jint | java.lang.Integer, /) -> None: ...
    def canRender(self, candidate: SliceSpec, /) -> bool: ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getRevision(self) -> int: ...
    def getType(self) -> str: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...



import typing

import android.content.res
import android.graphics
import android.os
import java
import java.chaquopy
import java.io
import java.lang
import java.nio
import java.util

class Font(java.lang.Object):
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAxes(self) -> java.chaquopy.JavaArray[FontVariationAxis] | None: ...
    def getBuffer(self) -> java.nio.ByteBuffer: ...
    def getFile(self) -> java.io.File | None: ...
    def getGlyphBounds(self, glyphId: int | java.jint | java.lang.Integer, paint: android.graphics.Paint, outBoundingBox: android.graphics.RectF, /) -> float: ...
    def getLocaleList(self) -> android.os.LocaleList: ...
    def getMetrics(self, paint: android.graphics.Paint, outMetrics: android.graphics.Paint.FontMetrics, /) -> None: ...
    def getSourceIdentifier(self) -> int: ...
    def getStyle(self) -> FontStyle: ...
    def getTtcIndex(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self, font: Font, /) -> None: ...
        @typing.overload
        def __init__(self, fd: android.os.ParcelFileDescriptor, /) -> None: ...
        @typing.overload
        def __init__(self, path: java.io.File, /) -> None: ...
        @typing.overload
        def __init__(self, buffer: java.nio.ByteBuffer, /) -> None: ...
        @typing.overload
        def __init__(self, am: android.content.res.AssetManager, path: str | java.lang.String, /) -> None: ...
        @typing.overload
        def __init__(self, res: android.content.res.Resources, resId: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, fd: android.os.ParcelFileDescriptor, offset: int | java.jlong | java.lang.Long, size: int | java.jlong | java.lang.Long, /) -> None: ...
        def build(self) -> Font: ...
        @typing.overload
        def setFontVariationSettings(self, variationSettings: str | java.lang.String, /) -> Font.Builder: ...
        @typing.overload
        def setFontVariationSettings(self, axes: java.chaquopy.JavaArray[FontVariationAxis], /) -> Font.Builder: ...
        def setSlant(self, slant: int | java.jint | java.lang.Integer, /) -> Font.Builder: ...
        def setTtcIndex(self, ttcIndex: int | java.jint | java.lang.Integer, /) -> Font.Builder: ...
        def setWeight(self, weight: int | java.jint | java.lang.Integer, /) -> Font.Builder: ...

class FontFamily(java.lang.Object):
    def getFont(self, index: int | java.jint | java.lang.Integer, /) -> Font: ...
    def getSize(self) -> int: ...

    class Builder(java.lang.Object):
        def __init__(self, font: Font, /) -> None: ...
        def addFont(self, font: Font, /) -> FontFamily.Builder: ...
        def build(self) -> FontFamily: ...
        def buildVariableFamily(self) -> FontFamily: ...

class FontStyle(java.lang.Object):
    FONT_SLANT_ITALIC: typing.ClassVar[int] = ...
    FONT_SLANT_UPRIGHT: typing.ClassVar[int] = ...
    FONT_WEIGHT_BLACK: typing.ClassVar[int] = ...
    FONT_WEIGHT_BOLD: typing.ClassVar[int] = ...
    FONT_WEIGHT_EXTRA_BOLD: typing.ClassVar[int] = ...
    FONT_WEIGHT_EXTRA_LIGHT: typing.ClassVar[int] = ...
    FONT_WEIGHT_LIGHT: typing.ClassVar[int] = ...
    FONT_WEIGHT_MAX: typing.ClassVar[int] = ...
    FONT_WEIGHT_MEDIUM: typing.ClassVar[int] = ...
    FONT_WEIGHT_MIN: typing.ClassVar[int] = ...
    FONT_WEIGHT_NORMAL: typing.ClassVar[int] = ...
    FONT_WEIGHT_SEMI_BOLD: typing.ClassVar[int] = ...
    FONT_WEIGHT_THIN: typing.ClassVar[int] = ...
    FONT_WEIGHT_UNSPECIFIED: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, weight: int | java.jint | java.lang.Integer, slant: int | java.jint | java.lang.Integer, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getSlant(self) -> int: ...
    def getWeight(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class FontVariationAxis(java.lang.Object):
    def __init__(self, tagString: str | java.lang.String, styleValue: float | java.jfloat | java.lang.Float, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def fromFontVariationSettings(settings: str | java.lang.String, /) -> java.chaquopy.JavaArray[FontVariationAxis] | None: ...
    def getStyleValue(self) -> float: ...
    def getTag(self) -> str: ...
    def hashCode(self) -> int: ...
    @staticmethod
    def toFontVariationSettings(axes: java.chaquopy.JavaArray[FontVariationAxis], /) -> str: ...
    def toString(self) -> str: ...

class SystemFonts(java.lang.Object):
    @staticmethod
    def getAvailableFonts() -> java.util.Set[Font]: ...



import typing

import android.os
import android.util
import java
import java.lang

class VibratorEnvelopeEffectInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[VibratorEnvelopeEffectInfo]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getMaxControlPointDurationMillis(self) -> int: ...
    def getMaxDurationMillis(self) -> int: ...
    def getMaxSize(self) -> int: ...
    def getMinControlPointDurationMillis(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class VibratorFrequencyProfile(java.lang.Object):
    def getFrequenciesOutputAcceleration(self) -> android.util.SparseArray[java.lang.Float]: ...
    def getFrequencyRange(self, minOutputAccelerationGs: float | java.jfloat | java.lang.Float, /) -> android.util.Range[java.lang.Float]: ...
    def getMaxFrequencyHz(self) -> float: ...
    def getMaxOutputAccelerationGs(self) -> float: ...
    def getMinFrequencyHz(self) -> float: ...
    def getOutputAccelerationGs(self, frequencyHz: float | java.jfloat | java.lang.Float, /) -> float: ...



import typing

import android.content
import android.database
import android.os
import android.util
import java
import java.chaquopy
import java.io
import java.lang
import java.util
import java.util.function
import java.util.regex

class SQLiteAbortException(SQLiteException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, error: str | java.lang.String, /) -> None: ...

class SQLiteAccessPermException(SQLiteException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, error: str | java.lang.String, /) -> None: ...

class SQLiteBindOrColumnIndexOutOfRangeException(SQLiteException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, error: str | java.lang.String, /) -> None: ...

class SQLiteBlobTooBigException(SQLiteException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, error: str | java.lang.String, /) -> None: ...

class SQLiteCantOpenDatabaseException(SQLiteException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, error: str | java.lang.String, /) -> None: ...

class SQLiteClosable(java.io.Closeable):
    def __init__(self) -> None: ...
    def acquireReference(self) -> None: ...
    def close(self) -> None: ...
    def onAllReferencesReleased(self) -> None: ...
    def onAllReferencesReleasedFromContainer(self) -> None: ...
    def releaseReference(self) -> None: ...
    def releaseReferenceFromContainer(self) -> None: ...

class SQLiteConstraintException(SQLiteException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, error: str | java.lang.String, /) -> None: ...

class SQLiteCursor(android.database.AbstractWindowedCursor):
    @typing.overload
    def __init__(self, driver: SQLiteCursorDriver, editTable: str | java.lang.String, query: SQLiteQuery, /) -> None: ...
    @typing.overload
    def __init__(self, db: SQLiteDatabase, driver: SQLiteCursorDriver, editTable: str | java.lang.String, query: SQLiteQuery, /) -> None: ...
    def close(self) -> None: ...
    def deactivate(self) -> None: ...
    def finalize(self) -> None: ...
    def getColumnIndex(self, columnName: str | java.lang.String, /) -> int: ...
    def getColumnNames(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getCount(self) -> int: ...
    def getDatabase(self) -> SQLiteDatabase: ...
    def onMove(self, oldPosition: int | java.jint | java.lang.Integer, newPosition: int | java.jint | java.lang.Integer, /) -> bool: ...
    def requery(self) -> bool: ...
    def setFillWindowForwardOnly(self, fillWindowForwardOnly: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSelectionArguments(self, selectionArgs: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def setWindow(self, window: android.database.CursorWindow, /) -> None: ...

class SQLiteCursorDriver(java.lang.Object):
    def cursorClosed(self) -> None: ...
    def cursorDeactivated(self) -> None: ...
    def cursorRequeried(self, arg1: android.database.Cursor, /) -> None: ...
    def query(self, arg1: SQLiteDatabase.CursorFactory, arg2: java.chaquopy.JavaArray[java.lang.String], /) -> android.database.Cursor: ...
    def setBindArguments(self, arg1: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...

class SQLiteDatabase(SQLiteClosable):
    CONFLICT_ABORT: typing.ClassVar[int] = ...
    CONFLICT_FAIL: typing.ClassVar[int] = ...
    CONFLICT_IGNORE: typing.ClassVar[int] = ...
    CONFLICT_NONE: typing.ClassVar[int] = ...
    CONFLICT_REPLACE: typing.ClassVar[int] = ...
    CONFLICT_ROLLBACK: typing.ClassVar[int] = ...
    CREATE_IF_NECESSARY: typing.ClassVar[int] = ...
    ENABLE_WRITE_AHEAD_LOGGING: typing.ClassVar[int] = ...
    JOURNAL_MODE_DELETE: typing.ClassVar[str] = ...
    JOURNAL_MODE_MEMORY: typing.ClassVar[str] = ...
    JOURNAL_MODE_OFF: typing.ClassVar[str] = ...
    JOURNAL_MODE_PERSIST: typing.ClassVar[str] = ...
    JOURNAL_MODE_TRUNCATE: typing.ClassVar[str] = ...
    JOURNAL_MODE_WAL: typing.ClassVar[str] = ...
    MAX_SQL_CACHE_SIZE: typing.ClassVar[int] = ...
    NO_LOCALIZED_COLLATORS: typing.ClassVar[int] = ...
    OPEN_READONLY: typing.ClassVar[int] = ...
    OPEN_READWRITE: typing.ClassVar[int] = ...
    SQLITE_MAX_LIKE_PATTERN_LENGTH: typing.ClassVar[int] = ...
    SYNC_MODE_EXTRA: typing.ClassVar[str] = ...
    SYNC_MODE_FULL: typing.ClassVar[str] = ...
    SYNC_MODE_NORMAL: typing.ClassVar[str] = ...
    SYNC_MODE_OFF: typing.ClassVar[str] = ...
    def beginTransaction(self) -> None: ...
    def beginTransactionNonExclusive(self) -> None: ...
    def beginTransactionReadOnly(self) -> None: ...
    def beginTransactionWithListener(self, transactionListener: SQLiteTransactionListener, /) -> None: ...
    def beginTransactionWithListenerNonExclusive(self, transactionListener: SQLiteTransactionListener, /) -> None: ...
    def beginTransactionWithListenerReadOnly(self, transactionListener: SQLiteTransactionListener, /) -> None: ...
    def compileStatement(self, sql: str | java.lang.String, /) -> SQLiteStatement: ...
    @staticmethod
    def create(factory: SQLiteDatabase.CursorFactory, /) -> SQLiteDatabase: ...
    @staticmethod
    def createInMemory(openParams: SQLiteDatabase.OpenParams, /) -> SQLiteDatabase: ...
    def createRawStatement(self, sql: str | java.lang.String, /) -> SQLiteRawStatement: ...
    def delete(self, table: str | java.lang.String, whereClause: str | java.lang.String, whereArgs: java.chaquopy.JavaArray[java.lang.String], /) -> int: ...
    @staticmethod
    def deleteDatabase(file: java.io.File, /) -> bool: ...
    def disableWriteAheadLogging(self) -> None: ...
    def enableWriteAheadLogging(self) -> bool: ...
    def endTransaction(self) -> None: ...
    def execPerConnectionSQL(self, sql: str | java.lang.String, bindArgs: java.chaquopy.JavaArray[java.lang.Object], /) -> None: ...
    @typing.overload
    def execSQL(self, sql: str | java.lang.String, /) -> None: ...
    @typing.overload
    def execSQL(self, sql: str | java.lang.String, bindArgs: java.chaquopy.JavaArray[java.lang.Object], /) -> None: ...
    def finalize(self) -> None: ...
    @staticmethod
    def findEditTable(tables: str | java.lang.String, /) -> str: ...
    def getAttachedDbs(self) -> java.util.List[android.util.Pair[java.lang.String, java.lang.String]] | None: ...
    def getLastChangedRowCount(self) -> int: ...
    def getLastInsertRowId(self) -> int: ...
    def getMaximumSize(self) -> int: ...
    def getPageSize(self) -> int: ...
    def getPath(self) -> str: ...
    def getSyncedTables(self) -> java.util.Map[java.lang.String, java.lang.String]: ...
    def getTotalChangedRowCount(self) -> int: ...
    def getVersion(self) -> int: ...
    def inTransaction(self) -> bool: ...
    def insert(self, table: str | java.lang.String, nullColumnHack: str | java.lang.String, values: android.content.ContentValues, /) -> int: ...
    def insertOrThrow(self, table: str | java.lang.String, nullColumnHack: str | java.lang.String, values: android.content.ContentValues, /) -> int: ...
    def insertWithOnConflict(self, table: str | java.lang.String, nullColumnHack: str | java.lang.String, initialValues: android.content.ContentValues, conflictAlgorithm: int | java.jint | java.lang.Integer, /) -> int: ...
    def isDatabaseIntegrityOk(self) -> bool: ...
    def isDbLockedByCurrentThread(self) -> bool: ...
    def isDbLockedByOtherThreads(self) -> bool: ...
    def isOpen(self) -> bool: ...
    def isReadOnly(self) -> bool: ...
    def isWriteAheadLoggingEnabled(self) -> bool: ...
    @typing.overload
    def markTableSyncable(self, table: str | java.lang.String, deletedTable: str | java.lang.String, /) -> None: ...
    @typing.overload
    def markTableSyncable(self, table: str | java.lang.String, foreignKey: str | java.lang.String, updateTable: str | java.lang.String, /) -> None: ...
    def needUpgrade(self, newVersion: int | java.jint | java.lang.Integer, /) -> bool: ...
    def onAllReferencesReleased(self) -> None: ...
    @typing.overload
    @staticmethod
    def openDatabase(path: java.io.File, openParams: SQLiteDatabase.OpenParams, /) -> SQLiteDatabase | None: ...
    @typing.overload
    @staticmethod
    def openDatabase(path: str | java.lang.String, factory: SQLiteDatabase.CursorFactory, flags: int | java.jint | java.lang.Integer, /) -> SQLiteDatabase | None: ...
    @typing.overload
    @staticmethod
    def openDatabase(path: str | java.lang.String, factory: SQLiteDatabase.CursorFactory, flags: int | java.jint | java.lang.Integer, errorHandler: android.database.DatabaseErrorHandler, /) -> SQLiteDatabase | None: ...
    @typing.overload
    @staticmethod
    def openOrCreateDatabase(file: java.io.File, factory: SQLiteDatabase.CursorFactory, /) -> SQLiteDatabase | None: ...
    @typing.overload
    @staticmethod
    def openOrCreateDatabase(path: str | java.lang.String, factory: SQLiteDatabase.CursorFactory, /) -> SQLiteDatabase | None: ...
    @typing.overload
    @staticmethod
    def openOrCreateDatabase(path: str | java.lang.String, factory: SQLiteDatabase.CursorFactory, errorHandler: android.database.DatabaseErrorHandler, /) -> SQLiteDatabase | None: ...
    @typing.overload
    def query(self, table: str | java.lang.String, columns: java.chaquopy.JavaArray[java.lang.String], selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], groupBy: str | java.lang.String, having: str | java.lang.String, orderBy: str | java.lang.String, /) -> android.database.Cursor | None: ...
    @typing.overload
    def query(self, table: str | java.lang.String, columns: java.chaquopy.JavaArray[java.lang.String], selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], groupBy: str | java.lang.String, having: str | java.lang.String, orderBy: str | java.lang.String, limit: str | java.lang.String, /) -> android.database.Cursor | None: ...
    @typing.overload
    def query(self, distinct: bool | java.jboolean | java.lang.Boolean, table: str | java.lang.String, columns: java.chaquopy.JavaArray[java.lang.String], selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], groupBy: str | java.lang.String, having: str | java.lang.String, orderBy: str | java.lang.String, limit: str | java.lang.String, /) -> android.database.Cursor | None: ...
    @typing.overload
    def query(self, distinct: bool | java.jboolean | java.lang.Boolean, table: str | java.lang.String, columns: java.chaquopy.JavaArray[java.lang.String], selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], groupBy: str | java.lang.String, having: str | java.lang.String, orderBy: str | java.lang.String, limit: str | java.lang.String, cancellationSignal: android.os.CancellationSignal, /) -> android.database.Cursor | None: ...
    @typing.overload
    def queryWithFactory(self, cursorFactory: SQLiteDatabase.CursorFactory, distinct: bool | java.jboolean | java.lang.Boolean, table: str | java.lang.String, columns: java.chaquopy.JavaArray[java.lang.String], selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], groupBy: str | java.lang.String, having: str | java.lang.String, orderBy: str | java.lang.String, limit: str | java.lang.String, /) -> android.database.Cursor | None: ...
    @typing.overload
    def queryWithFactory(self, cursorFactory: SQLiteDatabase.CursorFactory, distinct: bool | java.jboolean | java.lang.Boolean, table: str | java.lang.String, columns: java.chaquopy.JavaArray[java.lang.String], selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], groupBy: str | java.lang.String, having: str | java.lang.String, orderBy: str | java.lang.String, limit: str | java.lang.String, cancellationSignal: android.os.CancellationSignal, /) -> android.database.Cursor | None: ...
    @typing.overload
    def rawQuery(self, sql: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], /) -> android.database.Cursor: ...
    @typing.overload
    def rawQuery(self, sql: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], cancellationSignal: android.os.CancellationSignal, /) -> android.database.Cursor: ...
    @typing.overload
    def rawQueryWithFactory(self, cursorFactory: SQLiteDatabase.CursorFactory, sql: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], editTable: str | java.lang.String, /) -> android.database.Cursor | None: ...
    @typing.overload
    def rawQueryWithFactory(self, cursorFactory: SQLiteDatabase.CursorFactory, sql: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], editTable: str | java.lang.String, cancellationSignal: android.os.CancellationSignal, /) -> android.database.Cursor | None: ...
    @staticmethod
    def releaseMemory() -> int: ...
    def replace(self, table: str | java.lang.String, nullColumnHack: str | java.lang.String, initialValues: android.content.ContentValues, /) -> int: ...
    def replaceOrThrow(self, table: str | java.lang.String, nullColumnHack: str | java.lang.String, initialValues: android.content.ContentValues, /) -> int: ...
    def setCustomAggregateFunction(self, functionName: str | java.lang.String, aggregateFunction: java.util.function.BinaryOperator[java.lang.String], /) -> None: ...
    def setCustomScalarFunction(self, functionName: str | java.lang.String, scalarFunction: java.util.function.UnaryOperator[java.lang.String], /) -> None: ...
    def setForeignKeyConstraintsEnabled(self, enable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setLocale(self, locale: java.util.Locale, /) -> None: ...
    def setLockingEnabled(self, lockingEnabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setMaxSqlCacheSize(self, cacheSize: int | java.jint | java.lang.Integer, /) -> None: ...
    def setMaximumSize(self, numBytes: int | java.jlong | java.lang.Long, /) -> int: ...
    def setPageSize(self, numBytes: int | java.jlong | java.lang.Long, /) -> None: ...
    def setTransactionSuccessful(self) -> None: ...
    def setVersion(self, version: int | java.jint | java.lang.Integer, /) -> None: ...
    def toString(self) -> str: ...
    def update(self, table: str | java.lang.String, values: android.content.ContentValues, whereClause: str | java.lang.String, whereArgs: java.chaquopy.JavaArray[java.lang.String], /) -> int: ...
    def updateWithOnConflict(self, table: str | java.lang.String, values: android.content.ContentValues, whereClause: str | java.lang.String, whereArgs: java.chaquopy.JavaArray[java.lang.String], conflictAlgorithm: int | java.jint | java.lang.Integer, /) -> int: ...
    def validateSql(self, sql: str | java.lang.String, cancellationSignal: android.os.CancellationSignal, /) -> None: ...
    def yieldIfContended(self) -> bool: ...
    @typing.overload
    def yieldIfContendedSafely(self) -> bool: ...
    @typing.overload
    def yieldIfContendedSafely(self, sleepAfterYieldDelay: int | java.jlong | java.lang.Long, /) -> bool: ...

    class OpenParams(java.lang.Object):
        def getCursorFactory(self) -> SQLiteDatabase.CursorFactory: ...
        def getErrorHandler(self) -> android.database.DatabaseErrorHandler: ...
        def getIdleConnectionTimeout(self) -> int: ...
        def getJournalMode(self) -> str: ...
        def getLookasideSlotCount(self) -> int: ...
        def getLookasideSlotSize(self) -> int: ...
        def getOpenFlags(self) -> int: ...
        def getSynchronousMode(self) -> str: ...

        class Builder(java.lang.Object):
            @typing.overload
            def __init__(self) -> None: ...
            @typing.overload
            def __init__(self, params: SQLiteDatabase.OpenParams, /) -> None: ...
            def addOpenFlags(self, openFlags: int | java.jint | java.lang.Integer, /) -> SQLiteDatabase.OpenParams.Builder: ...
            def build(self) -> SQLiteDatabase.OpenParams: ...
            def removeOpenFlags(self, openFlags: int | java.jint | java.lang.Integer, /) -> SQLiteDatabase.OpenParams.Builder: ...
            def setCursorFactory(self, cursorFactory: SQLiteDatabase.CursorFactory, /) -> SQLiteDatabase.OpenParams.Builder: ...
            def setErrorHandler(self, errorHandler: android.database.DatabaseErrorHandler, /) -> SQLiteDatabase.OpenParams.Builder: ...
            def setIdleConnectionTimeout(self, idleConnectionTimeoutMs: int | java.jlong | java.lang.Long, /) -> SQLiteDatabase.OpenParams.Builder: ...
            def setJournalMode(self, journalMode: str | java.lang.String, /) -> SQLiteDatabase.OpenParams.Builder: ...
            def setLookasideConfig(self, slotSize: int | java.jint | java.lang.Integer, slotCount: int | java.jint | java.lang.Integer, /) -> SQLiteDatabase.OpenParams.Builder: ...
            def setOpenFlags(self, openFlags: int | java.jint | java.lang.Integer, /) -> SQLiteDatabase.OpenParams.Builder: ...
            def setSynchronousMode(self, syncMode: str | java.lang.String, /) -> SQLiteDatabase.OpenParams.Builder: ...

    class CursorFactory(java.lang.Object):
        def newCursor(self, arg1: SQLiteDatabase, arg2: SQLiteCursorDriver, arg3: str | java.lang.String, arg4: SQLiteQuery, /) -> android.database.Cursor: ...

class SQLiteDatabaseCorruptException(SQLiteException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, error: str | java.lang.String, /) -> None: ...

class SQLiteDatabaseLockedException(SQLiteException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, error: str | java.lang.String, /) -> None: ...

class SQLiteDatatypeMismatchException(SQLiteException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, error: str | java.lang.String, /) -> None: ...

class SQLiteDiskIOException(SQLiteException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, error: str | java.lang.String, /) -> None: ...

class SQLiteDoneException(SQLiteException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, error: str | java.lang.String, /) -> None: ...

class SQLiteException(android.database.SQLException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, error: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, error: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...

class SQLiteFullException(SQLiteException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, error: str | java.lang.String, /) -> None: ...

class SQLiteMisuseException(SQLiteException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, error: str | java.lang.String, /) -> None: ...

class SQLiteOpenHelper(java.lang.AutoCloseable):
    @typing.overload
    def __init__(self, context: android.content.Context, name: str | java.lang.String, version: int | java.jint | java.lang.Integer, openParams: SQLiteDatabase.OpenParams, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, name: str | java.lang.String, factory: SQLiteDatabase.CursorFactory, version: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, name: str | java.lang.String, factory: SQLiteDatabase.CursorFactory, version: int | java.jint | java.lang.Integer, errorHandler: android.database.DatabaseErrorHandler, /) -> None: ...
    def close(self) -> None: ...
    def getDatabaseName(self) -> str: ...
    def getReadableDatabase(self) -> SQLiteDatabase: ...
    def getWritableDatabase(self) -> SQLiteDatabase: ...
    def onConfigure(self, db: SQLiteDatabase, /) -> None: ...
    def onCreate(self, arg1: SQLiteDatabase, /) -> None: ...
    def onDowngrade(self, db: SQLiteDatabase, oldVersion: int | java.jint | java.lang.Integer, newVersion: int | java.jint | java.lang.Integer, /) -> None: ...
    def onOpen(self, db: SQLiteDatabase, /) -> None: ...
    def onUpgrade(self, arg1: SQLiteDatabase, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def setIdleConnectionTimeout(self, idleConnectionTimeoutMs: int | java.jlong | java.lang.Long, /) -> None: ...
    def setLookasideConfig(self, slotSize: int | java.jint | java.lang.Integer, slotCount: int | java.jint | java.lang.Integer, /) -> None: ...
    def setOpenParams(self, openParams: SQLiteDatabase.OpenParams, /) -> None: ...
    def setWriteAheadLoggingEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class SQLiteOutOfMemoryException(SQLiteException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, error: str | java.lang.String, /) -> None: ...

class SQLiteProgram(SQLiteClosable):
    def bindAllArgsAsStrings(self, bindArgs: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def bindBlob(self, index: int | java.jint | java.lang.Integer, value: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def bindDouble(self, index: int | java.jint | java.lang.Integer, value: float | java.jdouble | java.lang.Double, /) -> None: ...
    def bindLong(self, index: int | java.jint | java.lang.Integer, value: int | java.jlong | java.lang.Long, /) -> None: ...
    def bindNull(self, index: int | java.jint | java.lang.Integer, /) -> None: ...
    def bindString(self, index: int | java.jint | java.lang.Integer, value: str | java.lang.String, /) -> None: ...
    def clearBindings(self) -> None: ...
    def getUniqueId(self) -> int: ...
    def onAllReferencesReleased(self) -> None: ...

class SQLiteQuery(SQLiteProgram):
    def toString(self) -> str: ...

class SQLiteQueryBuilder(java.lang.Object):
    def __init__(self) -> None: ...
    @staticmethod
    def appendColumns(s: java.lang.StringBuilder, columns: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def appendWhere(self, inWhere: java.lang.CharSequence, /) -> None: ...
    def appendWhereEscapeString(self, inWhere: str | java.lang.String, /) -> None: ...
    def appendWhereStandalone(self, inWhere: java.lang.CharSequence, /) -> None: ...
    @typing.overload
    def buildQuery(self, projectionIn: java.chaquopy.JavaArray[java.lang.String], selection: str | java.lang.String, groupBy: str | java.lang.String, having: str | java.lang.String, sortOrder: str | java.lang.String, limit: str | java.lang.String, /) -> str: ...
    @typing.overload
    def buildQuery(self, projectionIn: java.chaquopy.JavaArray[java.lang.String], selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], groupBy: str | java.lang.String, having: str | java.lang.String, sortOrder: str | java.lang.String, limit: str | java.lang.String, /) -> str: ...
    @staticmethod
    def buildQueryString(distinct: bool | java.jboolean | java.lang.Boolean, tables: str | java.lang.String, columns: java.chaquopy.JavaArray[java.lang.String], where: str | java.lang.String, groupBy: str | java.lang.String, having: str | java.lang.String, orderBy: str | java.lang.String, limit: str | java.lang.String, /) -> str: ...
    def buildUnionQuery(self, subQueries: java.chaquopy.JavaArray[java.lang.String], sortOrder: str | java.lang.String, limit: str | java.lang.String, /) -> str: ...
    @typing.overload
    def buildUnionSubQuery(self, typeDiscriminatorColumn: str | java.lang.String, unionColumns: java.chaquopy.JavaArray[java.lang.String], columnsPresentInTable: java.util.Set[java.lang.String], computedColumnsOffset: int | java.jint | java.lang.Integer, typeDiscriminatorValue: str | java.lang.String, selection: str | java.lang.String, groupBy: str | java.lang.String, having: str | java.lang.String, /) -> str: ...
    @typing.overload
    def buildUnionSubQuery(self, typeDiscriminatorColumn: str | java.lang.String, unionColumns: java.chaquopy.JavaArray[java.lang.String], columnsPresentInTable: java.util.Set[java.lang.String], computedColumnsOffset: int | java.jint | java.lang.Integer, typeDiscriminatorValue: str | java.lang.String, selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], groupBy: str | java.lang.String, having: str | java.lang.String, /) -> str: ...
    def delete(self, db: SQLiteDatabase, selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], /) -> int: ...
    def getCursorFactory(self) -> SQLiteDatabase.CursorFactory | None: ...
    def getProjectionGreylist(self) -> java.util.Collection[java.util.regex.Pattern] | None: ...
    def getProjectionMap(self) -> java.util.Map[java.lang.String, java.lang.String] | None: ...
    def getTables(self) -> str | None: ...
    def insert(self, db: SQLiteDatabase, values: android.content.ContentValues, /) -> int: ...
    def isDistinct(self) -> bool: ...
    def isStrict(self) -> bool: ...
    def isStrictColumns(self) -> bool: ...
    def isStrictGrammar(self) -> bool: ...
    @typing.overload
    def query(self, db: SQLiteDatabase, projectionIn: java.chaquopy.JavaArray[java.lang.String], selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], groupBy: str | java.lang.String, having: str | java.lang.String, sortOrder: str | java.lang.String, /) -> android.database.Cursor: ...
    @typing.overload
    def query(self, db: SQLiteDatabase, projectionIn: java.chaquopy.JavaArray[java.lang.String], selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], groupBy: str | java.lang.String, having: str | java.lang.String, sortOrder: str | java.lang.String, limit: str | java.lang.String, /) -> android.database.Cursor: ...
    @typing.overload
    def query(self, db: SQLiteDatabase, projectionIn: java.chaquopy.JavaArray[java.lang.String], selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], groupBy: str | java.lang.String, having: str | java.lang.String, sortOrder: str | java.lang.String, limit: str | java.lang.String, cancellationSignal: android.os.CancellationSignal, /) -> android.database.Cursor: ...
    def setCursorFactory(self, factory: SQLiteDatabase.CursorFactory, /) -> None: ...
    def setDistinct(self, distinct: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setProjectionGreylist(self, projectionGreylist: java.util.Collection[java.util.regex.Pattern], /) -> None: ...
    def setProjectionMap(self, columnMap: java.util.Map[java.lang.String, java.lang.String], /) -> None: ...
    def setStrict(self, strict: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setStrictColumns(self, strictColumns: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setStrictGrammar(self, strictGrammar: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setTables(self, inTables: str | java.lang.String, /) -> None: ...
    def update(self, db: SQLiteDatabase, values: android.content.ContentValues, selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], /) -> int: ...

class SQLiteRawStatement(java.io.Closeable):
    SQLITE_DATA_TYPE_BLOB: typing.ClassVar[int] = ...
    SQLITE_DATA_TYPE_FLOAT: typing.ClassVar[int] = ...
    SQLITE_DATA_TYPE_INTEGER: typing.ClassVar[int] = ...
    SQLITE_DATA_TYPE_NULL: typing.ClassVar[int] = ...
    SQLITE_DATA_TYPE_TEXT: typing.ClassVar[int] = ...
    @typing.overload
    def bindBlob(self, parameterIndex: int | java.jint | java.lang.Integer, value: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @typing.overload
    def bindBlob(self, parameterIndex: int | java.jint | java.lang.Integer, value: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, /) -> None: ...
    def bindDouble(self, parameterIndex: int | java.jint | java.lang.Integer, value: float | java.jdouble | java.lang.Double, /) -> None: ...
    def bindInt(self, parameterIndex: int | java.jint | java.lang.Integer, value: int | java.jint | java.lang.Integer, /) -> None: ...
    def bindLong(self, parameterIndex: int | java.jint | java.lang.Integer, value: int | java.jlong | java.lang.Long, /) -> None: ...
    def bindNull(self, parameterIndex: int | java.jint | java.lang.Integer, /) -> None: ...
    def bindText(self, parameterIndex: int | java.jint | java.lang.Integer, value: str | java.lang.String, /) -> None: ...
    def clearBindings(self) -> None: ...
    def close(self) -> None: ...
    def getColumnBlob(self, columnIndex: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJByte | None: ...
    def getColumnDouble(self, columnIndex: int | java.jint | java.lang.Integer, /) -> float: ...
    def getColumnInt(self, columnIndex: int | java.jint | java.lang.Integer, /) -> int: ...
    def getColumnLength(self, columnIndex: int | java.jint | java.lang.Integer, /) -> int: ...
    def getColumnLong(self, columnIndex: int | java.jint | java.lang.Integer, /) -> int: ...
    def getColumnName(self, columnIndex: int | java.jint | java.lang.Integer, /) -> str: ...
    def getColumnText(self, columnIndex: int | java.jint | java.lang.Integer, /) -> str: ...
    def getColumnType(self, columnIndex: int | java.jint | java.lang.Integer, /) -> int: ...
    def getParameterCount(self) -> int: ...
    def getParameterIndex(self, name: str | java.lang.String, /) -> int: ...
    def getParameterName(self, parameterIndex: int | java.jint | java.lang.Integer, /) -> str | None: ...
    def getResultColumnCount(self) -> int: ...
    def isOpen(self) -> bool: ...
    def readColumnBlob(self, columnIndex: int | java.jint | java.lang.Integer, buffer: java.chaquopy.JavaArrayJByte, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, srcOffset: int | java.jint | java.lang.Integer, /) -> int: ...
    def reset(self) -> None: ...
    def step(self) -> bool: ...
    def toString(self) -> str: ...

class SQLiteReadOnlyDatabaseException(SQLiteException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, error: str | java.lang.String, /) -> None: ...

class SQLiteStatement(SQLiteProgram):
    def execute(self) -> None: ...
    def executeInsert(self) -> int: ...
    def executeUpdateDelete(self) -> int: ...
    def simpleQueryForBlobFileDescriptor(self) -> android.os.ParcelFileDescriptor: ...
    def simpleQueryForLong(self) -> int: ...
    def simpleQueryForString(self) -> str: ...
    def toString(self) -> str: ...

class SQLiteTableLockedException(SQLiteException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, error: str | java.lang.String, /) -> None: ...

class SQLiteTransactionListener(java.lang.Object):
    def onBegin(self) -> None: ...
    def onCommit(self) -> None: ...
    def onRollback(self) -> None: ...



import typing

import android.graphics
import android.graphics.fonts
import android.os
import java
import java.chaquopy
import java.lang

class LineBreakConfig(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[LineBreakConfig]] = ...
    HYPHENATION_DISABLED: typing.ClassVar[int] = ...
    HYPHENATION_ENABLED: typing.ClassVar[int] = ...
    HYPHENATION_UNSPECIFIED: typing.ClassVar[int] = ...
    LINE_BREAK_STYLE_AUTO: typing.ClassVar[int] = ...
    LINE_BREAK_STYLE_LOOSE: typing.ClassVar[int] = ...
    LINE_BREAK_STYLE_NONE: typing.ClassVar[int] = ...
    LINE_BREAK_STYLE_NORMAL: typing.ClassVar[int] = ...
    LINE_BREAK_STYLE_NO_BREAK: typing.ClassVar[int] = ...
    LINE_BREAK_STYLE_STRICT: typing.ClassVar[int] = ...
    LINE_BREAK_STYLE_UNSPECIFIED: typing.ClassVar[int] = ...
    LINE_BREAK_WORD_STYLE_AUTO: typing.ClassVar[int] = ...
    LINE_BREAK_WORD_STYLE_NONE: typing.ClassVar[int] = ...
    LINE_BREAK_WORD_STYLE_PHRASE: typing.ClassVar[int] = ...
    LINE_BREAK_WORD_STYLE_UNSPECIFIED: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getHyphenation(self) -> int: ...
    def getLineBreakStyle(self) -> int: ...
    def getLineBreakWordStyle(self) -> int: ...
    def hashCode(self) -> int: ...
    def merge(self, config: LineBreakConfig, /) -> LineBreakConfig: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> LineBreakConfig: ...
        def merge(self, config: LineBreakConfig, /) -> LineBreakConfig.Builder: ...
        def setHyphenation(self, hyphenation: int | java.jint | java.lang.Integer, /) -> LineBreakConfig.Builder: ...
        def setLineBreakStyle(self, lineBreakStyle: int | java.jint | java.lang.Integer, /) -> LineBreakConfig.Builder: ...
        def setLineBreakWordStyle(self, lineBreakWordStyle: int | java.jint | java.lang.Integer, /) -> LineBreakConfig.Builder: ...

class LineBreaker(java.lang.Object):
    BREAK_STRATEGY_BALANCED: typing.ClassVar[int] = ...
    BREAK_STRATEGY_HIGH_QUALITY: typing.ClassVar[int] = ...
    BREAK_STRATEGY_SIMPLE: typing.ClassVar[int] = ...
    HYPHENATION_FREQUENCY_FULL: typing.ClassVar[int] = ...
    HYPHENATION_FREQUENCY_NONE: typing.ClassVar[int] = ...
    HYPHENATION_FREQUENCY_NORMAL: typing.ClassVar[int] = ...
    JUSTIFICATION_MODE_INTER_CHARACTER: typing.ClassVar[int] = ...
    JUSTIFICATION_MODE_INTER_WORD: typing.ClassVar[int] = ...
    JUSTIFICATION_MODE_NONE: typing.ClassVar[int] = ...
    def computeLineBreaks(self, measuredPara: MeasuredText, constraints: LineBreaker.ParagraphConstraints, lineNumber: int | java.jint | java.lang.Integer, /) -> LineBreaker.Result: ...

    class Result(java.lang.Object):
        def getEndLineHyphenEdit(self, lineIndex: int | java.jint | java.lang.Integer, /) -> int: ...
        def getLineAscent(self, lineIndex: int | java.jint | java.lang.Integer, /) -> float: ...
        def getLineBreakOffset(self, lineIndex: int | java.jint | java.lang.Integer, /) -> int: ...
        def getLineCount(self) -> int: ...
        def getLineDescent(self, lineIndex: int | java.jint | java.lang.Integer, /) -> float: ...
        def getLineWidth(self, lineIndex: int | java.jint | java.lang.Integer, /) -> float: ...
        def getStartLineHyphenEdit(self, lineIndex: int | java.jint | java.lang.Integer, /) -> int: ...
        def hasLineTab(self, lineIndex: int | java.jint | java.lang.Integer, /) -> bool: ...

    class ParagraphConstraints(java.lang.Object):
        def __init__(self) -> None: ...
        def getDefaultTabStop(self) -> float: ...
        def getFirstWidth(self) -> float: ...
        def getFirstWidthLineCount(self) -> int: ...
        def getTabStops(self) -> java.chaquopy.JavaArrayJFloat: ...
        def getWidth(self) -> float: ...
        def setIndent(self, firstWidth: float | java.jfloat | java.lang.Float, firstWidthLineCount: int | java.jint | java.lang.Integer, /) -> None: ...
        def setTabStops(self, tabStops: java.chaquopy.JavaArrayJFloat, defaultTabStop: float | java.jfloat | java.lang.Float, /) -> None: ...
        def setWidth(self, width: float | java.jfloat | java.lang.Float, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> LineBreaker: ...
        def setBreakStrategy(self, breakStrategy: int | java.jint | java.lang.Integer, /) -> LineBreaker.Builder: ...
        def setHyphenationFrequency(self, hyphenationFrequency: int | java.jint | java.lang.Integer, /) -> LineBreaker.Builder: ...
        def setIndents(self, indents: java.chaquopy.JavaArrayJInt, /) -> LineBreaker.Builder: ...
        def setJustificationMode(self, justificationMode: int | java.jint | java.lang.Integer, /) -> LineBreaker.Builder: ...
        def setUseBoundsForWidth(self, useBoundsForWidth: bool | java.jboolean | java.lang.Boolean, /) -> LineBreaker.Builder: ...

class MeasuredText(java.lang.Object):
    def getBounds(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, rect: android.graphics.Rect, /) -> None: ...
    def getCharWidthAt(self, offset: int | java.jint | java.lang.Integer, /) -> float: ...
    def getFontMetricsInt(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, outMetrics: android.graphics.Paint.FontMetricsInt, /) -> None: ...
    def getWidth(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> float: ...

    class Builder(java.lang.Object):
        HYPHENATION_MODE_FAST: typing.ClassVar[int] = ...
        HYPHENATION_MODE_NONE: typing.ClassVar[int] = ...
        HYPHENATION_MODE_NORMAL: typing.ClassVar[int] = ...
        @typing.overload
        def __init__(self, text: MeasuredText, /) -> None: ...
        @typing.overload
        def __init__(self, text: java.chaquopy.JavaArrayJChar, /) -> None: ...
        def appendReplacementRun(self, paint: android.graphics.Paint, length: int | java.jint | java.lang.Integer, width: float | java.jfloat | java.lang.Float, /) -> MeasuredText.Builder: ...
        @typing.overload
        def appendStyleRun(self, paint: android.graphics.Paint, length: int | java.jint | java.lang.Integer, isRtl: bool | java.jboolean | java.lang.Boolean, /) -> MeasuredText.Builder: ...
        @typing.overload
        def appendStyleRun(self, paint: android.graphics.Paint, lineBreakConfig: LineBreakConfig, length: int | java.jint | java.lang.Integer, isRtl: bool | java.jboolean | java.lang.Boolean, /) -> MeasuredText.Builder: ...
        def build(self) -> MeasuredText: ...
        @typing.overload
        def setComputeHyphenation(self, mode: int | java.jint | java.lang.Integer, /) -> MeasuredText.Builder: ...
        @typing.overload
        def setComputeHyphenation(self, computeHyphenation: bool | java.jboolean | java.lang.Boolean, /) -> MeasuredText.Builder: ...
        def setComputeLayout(self, computeLayout: bool | java.jboolean | java.lang.Boolean, /) -> MeasuredText.Builder: ...

class PositionedGlyphs(java.lang.Object):
    NO_OVERRIDE: typing.ClassVar[float] = ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAdvance(self) -> float: ...
    def getAscent(self) -> float: ...
    def getDescent(self) -> float: ...
    def getFakeBold(self, index: int | java.jint | java.lang.Integer, /) -> bool: ...
    def getFakeItalic(self, index: int | java.jint | java.lang.Integer, /) -> bool: ...
    def getFont(self, index: int | java.jint | java.lang.Integer, /) -> android.graphics.fonts.Font: ...
    def getGlyphId(self, index: int | java.jint | java.lang.Integer, /) -> int: ...
    def getGlyphX(self, index: int | java.jint | java.lang.Integer, /) -> float: ...
    def getGlyphY(self, index: int | java.jint | java.lang.Integer, /) -> float: ...
    def getItalicOverride(self, index: int | java.jint | java.lang.Integer, /) -> float: ...
    def getOffsetX(self) -> float: ...
    def getOffsetY(self) -> float: ...
    def getWeightOverride(self, index: int | java.jint | java.lang.Integer, /) -> float: ...
    def glyphCount(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class TextRunShaper(java.lang.Object):
    @typing.overload
    @staticmethod
    def shapeTextRun(text: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, contextStart: int | java.jint | java.lang.Integer, contextCount: int | java.jint | java.lang.Integer, xOffset: float | java.jfloat | java.lang.Float, yOffset: float | java.jfloat | java.lang.Float, isRtl: bool | java.jboolean | java.lang.Boolean, paint: android.graphics.Paint, /) -> PositionedGlyphs: ...
    @typing.overload
    @staticmethod
    def shapeTextRun(text: java.chaquopy.JavaArrayJChar, start: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, contextStart: int | java.jint | java.lang.Integer, contextCount: int | java.jint | java.lang.Integer, xOffset: float | java.jfloat | java.lang.Float, yOffset: float | java.jfloat | java.lang.Float, isRtl: bool | java.jboolean | java.lang.Boolean, paint: android.graphics.Paint, /) -> PositionedGlyphs: ...



import typing

import android.net
import android.os
import java
import java.chaquopy
import java.lang
import java.net
import java.util

class ApnSetting(android.os.Parcelable):
    AUTH_TYPE_CHAP: typing.ClassVar[int] = ...
    AUTH_TYPE_NONE: typing.ClassVar[int] = ...
    AUTH_TYPE_PAP: typing.ClassVar[int] = ...
    AUTH_TYPE_PAP_OR_CHAP: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ApnSetting]] = ...
    MVNO_TYPE_GID: typing.ClassVar[int] = ...
    MVNO_TYPE_ICCID: typing.ClassVar[int] = ...
    MVNO_TYPE_IMSI: typing.ClassVar[int] = ...
    MVNO_TYPE_SPN: typing.ClassVar[int] = ...
    PROTOCOL_IP: typing.ClassVar[int] = ...
    PROTOCOL_IPV4V6: typing.ClassVar[int] = ...
    PROTOCOL_IPV6: typing.ClassVar[int] = ...
    PROTOCOL_NON_IP: typing.ClassVar[int] = ...
    PROTOCOL_PPP: typing.ClassVar[int] = ...
    PROTOCOL_UNSTRUCTURED: typing.ClassVar[int] = ...
    TYPE_BIP: typing.ClassVar[int] = ...
    TYPE_CBS: typing.ClassVar[int] = ...
    TYPE_DEFAULT: typing.ClassVar[int] = ...
    TYPE_DUN: typing.ClassVar[int] = ...
    TYPE_EMERGENCY: typing.ClassVar[int] = ...
    TYPE_ENTERPRISE: typing.ClassVar[int] = ...
    TYPE_FOTA: typing.ClassVar[int] = ...
    TYPE_HIPRI: typing.ClassVar[int] = ...
    TYPE_IA: typing.ClassVar[int] = ...
    TYPE_IMS: typing.ClassVar[int] = ...
    TYPE_MCX: typing.ClassVar[int] = ...
    TYPE_MMS: typing.ClassVar[int] = ...
    TYPE_OEM_PAID: typing.ClassVar[int] = ...
    TYPE_OEM_PRIVATE: typing.ClassVar[int] = ...
    TYPE_RCS: typing.ClassVar[int] = ...
    TYPE_SUPL: typing.ClassVar[int] = ...
    TYPE_VSIM: typing.ClassVar[int] = ...
    TYPE_XCAP: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getApnName(self) -> str: ...
    def getApnTypeBitmask(self) -> int: ...
    def getAuthType(self) -> int: ...
    def getCarrierId(self) -> int: ...
    def getEntryName(self) -> str: ...
    def getId(self) -> int: ...
    def getMmsProxyAddress(self) -> java.net.InetAddress: ...
    def getMmsProxyAddressAsString(self) -> str: ...
    def getMmsProxyPort(self) -> int: ...
    def getMmsc(self) -> android.net.Uri: ...
    def getMtuV4(self) -> int: ...
    def getMtuV6(self) -> int: ...
    def getMvnoType(self) -> int: ...
    def getNetworkTypeBitmask(self) -> int: ...
    def getOperatorNumeric(self) -> str: ...
    def getPassword(self) -> str: ...
    def getProfileId(self) -> int: ...
    def getProtocol(self) -> int: ...
    def getProxyAddress(self) -> java.net.InetAddress: ...
    def getProxyAddressAsString(self) -> str: ...
    def getProxyPort(self) -> int: ...
    def getRoamingProtocol(self) -> int: ...
    def getUser(self) -> str: ...
    def hashCode(self) -> int: ...
    def isAlwaysOn(self) -> bool: ...
    def isEnabled(self) -> bool: ...
    def isPersistent(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> ApnSetting: ...
        def setAlwaysOn(self, alwaysOn: bool | java.jboolean | java.lang.Boolean, /) -> ApnSetting.Builder: ...
        def setApnName(self, apnName: str | java.lang.String, /) -> ApnSetting.Builder: ...
        def setApnTypeBitmask(self, apnTypeBitmask: int | java.jint | java.lang.Integer, /) -> ApnSetting.Builder: ...
        def setAuthType(self, authType: int | java.jint | java.lang.Integer, /) -> ApnSetting.Builder: ...
        def setCarrierEnabled(self, carrierEnabled: bool | java.jboolean | java.lang.Boolean, /) -> ApnSetting.Builder: ...
        def setCarrierId(self, carrierId: int | java.jint | java.lang.Integer, /) -> ApnSetting.Builder: ...
        def setEntryName(self, entryName: str | java.lang.String, /) -> ApnSetting.Builder: ...
        @typing.overload
        def setMmsProxyAddress(self, mmsProxy: str | java.lang.String, /) -> ApnSetting.Builder: ...
        @typing.overload
        def setMmsProxyAddress(self, mmsProxy: java.net.InetAddress, /) -> ApnSetting.Builder: ...
        def setMmsProxyPort(self, mmsPort: int | java.jint | java.lang.Integer, /) -> ApnSetting.Builder: ...
        def setMmsc(self, mmsc: android.net.Uri, /) -> ApnSetting.Builder: ...
        def setMtuV4(self, mtuV4: int | java.jint | java.lang.Integer, /) -> ApnSetting.Builder: ...
        def setMtuV6(self, mtuV6: int | java.jint | java.lang.Integer, /) -> ApnSetting.Builder: ...
        def setMvnoType(self, mvnoType: int | java.jint | java.lang.Integer, /) -> ApnSetting.Builder: ...
        def setNetworkTypeBitmask(self, networkTypeBitmask: int | java.jint | java.lang.Integer, /) -> ApnSetting.Builder: ...
        def setOperatorNumeric(self, operatorNumeric: str | java.lang.String, /) -> ApnSetting.Builder: ...
        def setPassword(self, password: str | java.lang.String, /) -> ApnSetting.Builder: ...
        def setPersistent(self, isPersistent: bool | java.jboolean | java.lang.Boolean, /) -> ApnSetting.Builder: ...
        def setProfileId(self, profileId: int | java.jint | java.lang.Integer, /) -> ApnSetting.Builder: ...
        def setProtocol(self, protocol: int | java.jint | java.lang.Integer, /) -> ApnSetting.Builder: ...
        @typing.overload
        def setProxyAddress(self, proxy: str | java.lang.String, /) -> ApnSetting.Builder: ...
        @typing.overload
        def setProxyAddress(self, proxy: java.net.InetAddress, /) -> ApnSetting.Builder: ...
        def setProxyPort(self, port: int | java.jint | java.lang.Integer, /) -> ApnSetting.Builder: ...
        def setRoamingProtocol(self, roamingProtocol: int | java.jint | java.lang.Integer, /) -> ApnSetting.Builder: ...
        def setUser(self, user: str | java.lang.String, /) -> ApnSetting.Builder: ...

class NetworkSliceInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[NetworkSliceInfo]] = ...
    SLICE_DIFFERENTIATOR_NO_SLICE: typing.ClassVar[int] = ...
    SLICE_SERVICE_TYPE_EMBB: typing.ClassVar[int] = ...
    SLICE_SERVICE_TYPE_MIOT: typing.ClassVar[int] = ...
    SLICE_SERVICE_TYPE_NONE: typing.ClassVar[int] = ...
    SLICE_SERVICE_TYPE_URLLC: typing.ClassVar[int] = ...
    SLICE_STATUS_ALLOWED: typing.ClassVar[int] = ...
    SLICE_STATUS_CONFIGURED: typing.ClassVar[int] = ...
    SLICE_STATUS_DEFAULT_CONFIGURED: typing.ClassVar[int] = ...
    SLICE_STATUS_REJECTED_NOT_AVAILABLE_IN_PLMN: typing.ClassVar[int] = ...
    SLICE_STATUS_REJECTED_NOT_AVAILABLE_IN_REGISTERED_AREA: typing.ClassVar[int] = ...
    SLICE_STATUS_UNKNOWN: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getMappedHplmnSliceDifferentiator(self) -> int: ...
    def getMappedHplmnSliceServiceType(self) -> int: ...
    def getSliceDifferentiator(self) -> int: ...
    def getSliceServiceType(self) -> int: ...
    def getStatus(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> NetworkSliceInfo: ...
        def setMappedHplmnSliceDifferentiator(self, mappedHplmnSliceDifferentiator: int | java.jint | java.lang.Integer, /) -> NetworkSliceInfo.Builder: ...
        def setMappedHplmnSliceServiceType(self, mappedHplmnSliceServiceType: int | java.jint | java.lang.Integer, /) -> NetworkSliceInfo.Builder: ...
        def setSliceDifferentiator(self, sliceDifferentiator: int | java.jint | java.lang.Integer, /) -> NetworkSliceInfo.Builder: ...
        def setSliceServiceType(self, mSliceServiceType: int | java.jint | java.lang.Integer, /) -> NetworkSliceInfo.Builder: ...
        def setStatus(self, status: int | java.jint | java.lang.Integer, /) -> NetworkSliceInfo.Builder: ...

class NetworkSlicingConfig(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[NetworkSlicingConfig]] = ...
    def __init__(self) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getSliceInfo(self) -> java.util.List[NetworkSliceInfo]: ...
    def getUrspRules(self) -> java.util.List[UrspRule]: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class RouteSelectionDescriptor(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[RouteSelectionDescriptor]] = ...
    ROUTE_SSC_MODE_1: typing.ClassVar[int] = ...
    ROUTE_SSC_MODE_2: typing.ClassVar[int] = ...
    ROUTE_SSC_MODE_3: typing.ClassVar[int] = ...
    SESSION_TYPE_IPV4: typing.ClassVar[int] = ...
    SESSION_TYPE_IPV4V6: typing.ClassVar[int] = ...
    SESSION_TYPE_IPV6: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDataNetworkName(self) -> java.util.List[java.lang.String]: ...
    def getPrecedence(self) -> int: ...
    def getSessionType(self) -> int: ...
    def getSliceInfo(self) -> java.util.List[NetworkSliceInfo]: ...
    def getSscMode(self) -> int: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class TrafficDescriptor(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TrafficDescriptor]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getDataNetworkName(self) -> str | None: ...
    def getOsAppId(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> TrafficDescriptor: ...
        def setDataNetworkName(self, dnn: str | java.lang.String, /) -> TrafficDescriptor.Builder: ...
        def setOsAppId(self, osAppId: java.chaquopy.JavaArrayJByte, /) -> TrafficDescriptor.Builder: ...

class UrspRule(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[UrspRule]] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getPrecedence(self) -> int: ...
    def getRouteSelectionDescriptor(self) -> java.util.List[RouteSelectionDescriptor]: ...
    def getTrafficDescriptors(self) -> java.util.List[TrafficDescriptor]: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...
